use nalgebra::Vector4;
use rhai::{CustomType, TypeBuilder};

#[derive(Debug, Clone)]
pub struct Color {
	pub val: Vector4<f32>,
}

impl Color {
	pub fn new(r: f32, g: f32, b: f32, a: f32) -> Self {
		Self {
			val: Vector4::new(r, g, b, a),
		}
	}

	pub fn as_array(&self) -> [f32; 4] {
		[self.val.x, self.val.y, self.val.z, self.val.w]
	}
}

impl CustomType for Color {
	fn build(mut builder: TypeBuilder<Self>) {
		builder.with_name("Color").with_fn("Color", Self::new);
	}
}
