mod color;
mod config;
mod event;
mod radialbuilder;
mod rect;
mod sceneaction;
mod sprite;
mod spritebuilder;
mod state;
mod textboxbuilder;
mod util;

pub use color::*;
pub use config::*;
pub use event::*;
pub use radialbuilder::*;
pub use rect::*;
pub use sceneaction::*;
pub use sprite::*;
pub use spritebuilder::*;
pub use state::*;
pub use textboxbuilder::*;
pub use util::*;

use rhai::{exported_module, Engine};

pub fn register_into_engine(engine: &mut Engine) {
	engine
		.build_type::<State>()
		.build_type::<ShipState>()
		.build_type::<Rect>()
		.build_type::<Color>()
		.build_type::<RadialBuilder>()
		.build_type::<SpriteElement>()
		.build_type::<SceneConfig>()
		.build_type::<SpriteBuilder>()
		.build_type::<TextBoxBuilder>()
		.build_type::<MouseClickEvent>()
		.build_type::<MouseHoverEvent>()
		.build_type::<PlayerShipStateEvent>()
		.register_type_with_name::<SpriteAnchor>("SpriteAnchor")
		.register_static_module("SpriteAnchor", exported_module!(spriteanchor_mod).into())
		.register_type_with_name::<TextBoxFont>("TextBoxFont")
		.register_static_module(
			"TextBoxFont",
			exported_module!(util::textboxfont_mod).into(),
		)
		.register_type_with_name::<TextBoxJustify>("TextBoxJustify")
		.register_static_module(
			"TextBoxJustify",
			exported_module!(textboxjustify_mod).into(),
		)
		.register_type_with_name::<SceneAction>("SceneAction")
		.register_static_module("SceneAction", exported_module!(sceneaction_mod).into());
}
