use nalgebra::clamp;
use rhai::{CustomType, ImmutableString, TypeBuilder};

use super::{color::Color, Rect};

#[derive(Debug, Clone)]
pub struct RadialBuilder {
	pub name: ImmutableString,
	pub rect: Rect,

	pub stroke: f32,
	pub color: Color,
	pub progress: f32,
}

impl RadialBuilder {
	pub fn new(name: ImmutableString, stroke: f32, color: Color, rect: Rect) -> Self {
		Self {
			name,
			rect,
			stroke,
			color,
			progress: 0.0,
		}
	}

	pub fn set_progress(&mut self, progress: f32) {
		self.progress = clamp(progress, 0.0, 1.0);
	}
}

impl CustomType for RadialBuilder {
	fn build(mut builder: TypeBuilder<Self>) {
		builder
			.with_name("RadialBuilder")
			.with_fn("RadialBuilder", Self::new)
			.with_fn("set_progress", Self::set_progress);
	}
}
