use galactica_system::{data, phys::PhysSimShipHandle};
use rhai::{CustomType, TypeBuilder};
use std::rc::Rc;

use crate::RenderInput;

#[derive(Debug, Clone)]
pub struct ShipState {
	ship: Option<PhysSimShipHandle>,
	input: Rc<RenderInput>,
}

// TODO: remove this
unsafe impl Send for ShipState {}
unsafe impl Sync for ShipState {}

impl ShipState {
	pub fn get_state(&mut self) -> &data::ShipState {
		let ship = self
			.input
			.phys_img
			.get_ship(self.ship.as_ref().unwrap())
			.unwrap();
		ship.ship.get_data().get_state()
	}
}

impl CustomType for ShipState {
	fn build(mut builder: TypeBuilder<Self>) {
		builder
			.with_name("ShipState")
			.with_fn("is_some", |s: &mut Self| s.ship.is_some())
			.with_fn("is_dead", |s: &mut Self| s.get_state().is_dead())
			.with_fn("is_landed", |s: &mut Self| s.get_state().is_landed())
			.with_fn("is_landing", |s: &mut Self| s.get_state().is_landing())
			.with_fn("is_flying", |s: &mut Self| s.get_state().is_flying())
			.with_fn("is_unlanding", |s: &mut Self| s.get_state().is_unlanding())
			.with_fn("is_collapsing", |s: &mut Self| {
				s.get_state().is_collapsing()
			});
	}
}

#[derive(Debug, Clone)]
pub struct State {
	input: Rc<RenderInput>,
}

// TODO: remove this
unsafe impl Send for State {}
unsafe impl Sync for State {}

impl State {
	pub fn new(input: Rc<RenderInput>) -> Self {
		Self { input }
	}

	pub fn player_ship(&mut self) -> ShipState {
		ShipState {
			input: self.input.clone(),
			ship: self.input.player.ship.map(|x| PhysSimShipHandle(x)),
		}
	}
}

impl CustomType for State {
	fn build(mut builder: TypeBuilder<Self>) {
		builder
			.with_name("State")
			.with_fn("player_ship", Self::player_ship);
	}
}
