use rhai::{CustomType, ImmutableString, TypeBuilder};

use super::{Rect, TextBoxFont, TextBoxJustify};

#[derive(Debug, Clone)]
pub struct TextBoxBuilder {
	pub name: ImmutableString,
	pub font_size: f32,
	pub line_height: f32,
	pub font: TextBoxFont,
	pub justify: TextBoxJustify,
	pub rect: Rect,
	pub text: ImmutableString,
}

impl TextBoxBuilder {
	pub fn new(
		name: ImmutableString,
		font_size: f32,
		line_height: f32,
		font: TextBoxFont,
		justify: TextBoxJustify,
		rect: Rect,
	) -> Self {
		Self {
			name,
			font_size,
			line_height,
			font,
			justify,
			rect,
			text: ImmutableString::new(),
		}
	}

	pub fn set_text(&mut self, text: ImmutableString) {
		self.text = text
	}
}

impl CustomType for TextBoxBuilder {
	fn build(mut builder: TypeBuilder<Self>) {
		builder
			.with_name("TextBoxBuilder")
			.with_fn("TextBoxBuilder", Self::new)
			.with_fn("set_text", Self::set_text);
	}
}
