use std::{cell::RefCell, rc::Rc};

use super::util::{RadialBar, Sprite, TextBox};

#[derive(Debug)]
pub enum UiElement {
	Sprite(Rc<RefCell<Sprite>>),
	RadialBar(Rc<RefCell<RadialBar>>),
	Text(TextBox),
}

impl UiElement {
	pub fn new_sprite(sprite: Sprite) -> Self {
		Self::Sprite(Rc::new(RefCell::new(sprite)))
	}

	pub fn new_radialbar(bar: RadialBar) -> Self {
		Self::RadialBar(Rc::new(RefCell::new(bar)))
	}

	pub fn new_text(text: TextBox) -> Self {
		Self::Text(text)
	}

	pub fn text(&self) -> Option<&TextBox> {
		match self {
			Self::Text(t) => Some(t),
			_ => None,
		}
	}
}
