use galactica_content::Content;
use std::f32::consts::TAU;

use super::super::api::Rect;
use crate::{
	ui::api::Color, vertexbuffer::types::RadialBarInstance, PositionAnchor, RenderInput,
	RenderState,
};

#[derive(Debug, Clone)]
pub struct RadialBar {
	pub name: String,
	pub rect: Rect,
	pub stroke: f32,
	pub color: Color,
	pub progress: f32,
}

impl RadialBar {
	pub fn new(
		_ct: &Content,
		name: String,
		stroke: f32,
		color: Color,
		rect: Rect,
		progress: f32,
	) -> Self {
		Self {
			name,
			rect,
			stroke,
			color,
			progress,
		}
	}

	pub fn push_to_buffer(&self, input: &RenderInput, state: &mut RenderState) {
		let rect = self.rect.to_centered(state, input.ct.get_config().ui_scale);

		state.push_radialbar_buffer(RadialBarInstance {
			position: [rect.pos.x, rect.pos.y],
			anchor: PositionAnchor::CC.to_int(),
			diameter: rect.dim.x.min(rect.dim.y),
			stroke: self.stroke * input.ct.get_config().ui_scale,
			color: self.color.as_array(),
			angle: self.progress * TAU,
		});
	}

	pub fn step(&mut self, _input: &RenderInput, _state: &mut RenderState) {}
}
